# Learning Object-aware Anchor-free Networks for Real-time Object Tracking (Ocean)

- If you have any issue with running our tracker, please feel free to contact zhangzhipeng2017@ia.ac.cn .

## Important Files 
- Ocean/vot_Ocean.py <br/>
  The interface between our tracker with VOT2020 python toolkit.
- Ocean/install.sh <br/>
  The guidance of conda environment and python packages installation. 
- Ocean/lib <br/>
  Main Code of our tracker.
- Ocean/experiment <br/>
  Hyperparameters of our tracker.
- Ocean/snapshot  <br/>
  Pretrained models (empty).


## Running Environment
python3.7 <br/>
pytorch1.1.0 <br/>
cudatoolkit9.0 <br/>
Nvidia Tesla M40 (24GB) <br/>
Intel(R) Xeon(R) CPU E5-2690 v4 @ 2.60GHz <br/>

## Results (EAO)
| baseline | realtime | 
| ------ | ------ | 
|0.444	| 0.436 | 


## Run Tracker
### Note
- Before running our tracker, you may consider temporally stop other programs that take much CPU or GPU resources. Otherwise, it may bring negative effect on realtime running. If you only run the baseline experiment, please ignore this. 

### Step1. Set up the environment
In the code (Ocean),
```
bash install.sh $conda_path Ocean
```
`$conda_path` indicates your anaconda installation path, e.g. `/data/zpzhang/anaconda3`.

### Step2. Set up VOT2020 toolkit
step1 will automatically download vot toolkit.
```
mkdir vot-workspace
cd vot-workspace
vot workspace vot2020 --workspace <workspace-path>
cp $tracker_path/trackers.ini .
```
`<workspace-path>` indicates the absolute path of `vot-workspace`, e.g. `/data/zpzhang/vot-workspace`. `tracker_path` indicates the absolute path of our tracker, e.g. `/data/zpzahng/Ocean`.

### Step3. Download the pre-trained model
Please download the pre-trained model [here](https://drive.google.com/file/d/13to5q3f-AiZT_yKEA_oh1eGAc1X4GihD/view?usp=sharing). And then put it into `$tracker_path/snapshot/`

### Step4. Modify path in codes
- Modify `$tracker_path` of line7 in `<workspace-path>/trackers.ini`, e.g. `/data/zpzahng/Ocean`.
- Modify `$tracker_path` of line79 in `$tracker_path/vot_Ocean.py`, e.g. `/data/zpzahng/Ocean`.

### Step5. Run testing
In `vot-workspace`,
```
conda activate Ocean
CUDA_VISIBLE_DEVICES=$gpu_id vot evaluate --workspace <workspace-path> Ocean
```
`$gpu_id` indicates the ID of GPU that you plan to run the tracker.


### Step6. Get results
In `vot-workspace`,
```
vot analysis --workspace <workspace-path> Ocean --output json 
```
